tauri-hasgard-cli 0.1.0

CLI and MCP server for Tauri Hasgard automation
tauri-hasgard-cli-0.1.0 is not a library.

tauri-hasgard

CLI for interactive testing and automation of Tauri v2 applications.

See the Tauri Hasgard repository for the plugin setup, Playwright fixture, protocol, and MCP documentation.